@@ -26,50 +26,50 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #'  `terms` (the columns that will be affected) and `holiday` is returned.
 #'
+#' @template case-weights-not-supported
+#'
 #' @examples
 #' library(lubridate)
 #'
 #' examples <- data.frame(someday = ymd("2000-12-20") + days(0:40))
-#' holiday_rec <- recipe(~ someday, examples) %>%
-#'    step_holiday(all_predictors())
+#' holiday_rec <- recipe(~someday, examples) %>%
+#'   step_holiday(all_predictors())
 #'
 #' holiday_rec <- prep(holiday_rec, training = examples)
 #' holiday_values <- bake(holiday_rec, new_data = examples)
 #' holiday_values
 #' @import timeDate
 step_holiday <-
-  function(
-    recipe,
-    ...,
-    role = "predictor",
-    trained = FALSE,
-    holidays = c("LaborDay", "NewYearsDay", "ChristmasDay"),
-    columns = NULL,
-    keep_original_cols = TRUE,
-    skip = FALSE,
-    id = rand_id("holiday")
-  ) {
-
+  function(recipe,
+           ...,
+           role = "predictor",
+           trained = FALSE,
+           holidays = c("LaborDay", "NewYearsDay", "ChristmasDay"),
+           columns = NULL,
+           keep_original_cols = TRUE,
+           skip = FALSE,
+           id = rand_id("holiday")) {
     if (!is_tune(holidays) & !is_varying(holidays)) {
       all_days <- listHolidays()
-      if (!all(holidays %in% all_days))
+      if (!all(holidays %in% all_days)) {
         rlang::abort("Invalid `holidays` value. See timeDate::listHolidays")
+      }
     }
 
-  add_step(
-    recipe,
-    step_holiday_new(
-      terms = enquos(...),
-      role = role,
-      trained = trained,
-      holidays = holidays,
-      columns = columns,
-      keep_original_cols = keep_original_cols,
-      skip = skip,
-      id = id
+    add_step(
+      recipe,
+      step_holiday_new(
+        terms = enquos(...),
+        role = role,
+        trained = trained,
+        holidays = holidays,
+        columns = columns,
+        keep_original_cols = keep_original_cols,
+        skip = skip,
+        id = id
+      )
     )
-  )
-}
+  }
 
 step_holiday_new <-
   function(terms, role, trained, holidays, columns, keep_original_cols, skip, id) {
@@ -91,13 +91,14 @@ prep.step_holiday <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
 
   holiday_data <- info[info$variable %in% col_names, ]
-  if (any(holiday_data$type != "date"))
+  if (any(holiday_data$type != "date")) {
     rlang::abort(
       paste0(
         "All variables for `step_holiday` should be either `Date` ",
         "or `POSIXct` classes."
-         )
+      )
     )
+  }
 
   step_holiday_new(
     terms = x$terms,
@@ -111,12 +112,15 @@ prep.step_holiday <- function(x, training, info = NULL, ...) {
   )
 }
 
-
 is_holiday <- function(hol, dt) {
-  hdate <- holiday(year = unique(year(dt)), Holiday = hol)
+  years <- unique(year(dt))
+  na_year <- which(is.na(years))
+  years <- years[-na_year]
+  hdate <- holiday(year = years, Holiday = hol)
   hdate <- as.Date(hdate)
   out <- rep(0, length(dt))
   out[dt %in% hdate] <- 1
+  out[is.na(dt)] <- NA
   out
 }
 
@@ -133,9 +137,13 @@ get_holiday_features <- function(dt, hdays) {
 
 #' @export
 bake.step_holiday <- function(object, new_data, ...) {
+  check_new_data(names(object$columns), object, new_data)
+
   for (i in seq_along(object$columns)) {
-    tmp <- get_holiday_features(dt = new_data[[ object$columns[i] ]],
-                                hdays = object$holidays)
+    tmp <- get_holiday_features(
+      dt = new_data[[object$columns[i]]],
+      hdays = object$holidays
+    )
 
     names(tmp) <- paste(object$columns[i], names(tmp), sep = "_")
     new_data <- bind_cols(new_data, tmp)
@@ -145,10 +153,6 @@ bake.step_holiday <- function(object, new_data, ...) {
   if (!keep_original_cols) {
     new_data <- new_data[, !(colnames(new_data) %in% object$columns), drop = FALSE]
   }
-
-  if (!is_tibble(new_data)) {
-    new_data <- as_tibble(new_data)
-  }
   new_data
 }
 
