@@ -46,11 +46,13 @@
 #'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #'  `terms` (the selectors or variables selected) and `model`
 #'  (the bagged tree object) is returned.
+#'
+#' @template case-weights-not-supported
+#'
 #' @references Kuhn, M. and Johnson, K. (2013). *Applied Predictive Modeling*.
 #'  Springer Verlag.
-#' @examples
-#' library(modeldata)
-#' data("credit_data")
+#' @examplesIf rlang::is_installed("modeldata")
+#' data("credit_data", package = "modeldata")
 #'
 #' ## missing data per column
 #' vapply(credit_data, function(x) mean(is.na(x)), c(num = 0))
@@ -58,7 +60,7 @@
 #' set.seed(342)
 #' in_training <- sample(1:nrow(credit_data), 2000)
 #'
-#' credit_tr <- credit_data[ in_training, ]
+#' credit_tr <- credit_data[in_training, ]
 #' credit_te <- credit_data[-in_training, ]
 #' missing_examples <- c(14, 394, 565)
 #'
@@ -71,7 +73,7 @@
 #'
 #' imputed_te <- bake(imp_models, new_data = credit_te, everything())
 #'
-#' credit_te[missing_examples,]
+#' credit_te[missing_examples, ]
 #' imputed_te[missing_examples, names(credit_te)]
 #'
 #' tidy(impute_rec, number = 1)
@@ -79,23 +81,23 @@
 #'
 #' ## Specifying which variables to imputate with
 #'
-#'  impute_rec <- rec %>%
+#' impute_rec <- rec %>%
 #'   step_impute_bag(Status, Home, Marital, Job, Income, Assets, Debt,
-#'                  impute_with = imp_vars(Time, Age, Expenses),
-#'                  # for quick execution, nbagg lowered
-#'                  options = list(nbagg = 5, keepX = FALSE))
+#'     impute_with = imp_vars(Time, Age, Expenses),
+#'     # for quick execution, nbagg lowered
+#'     options = list(nbagg = 5, keepX = FALSE)
+#'   )
 #'
 #' imp_models <- prep(impute_rec, training = credit_tr)
 #'
 #' imputed_te <- bake(imp_models, new_data = credit_te, everything())
 #'
-#' credit_te[missing_examples,]
+#' credit_te[missing_examples, ]
 #' imputed_te[missing_examples, names(credit_te)]
 #'
 #' tidy(impute_rec, number = 1)
 #' tidy(imp_models, number = 1)
 #' }
-
 step_impute_bag <-
   function(recipe,
            ...,
@@ -105,11 +107,12 @@ step_impute_bag <-
            trees = 25,
            models = NULL,
            options = list(keepX = FALSE),
-           seed_val = sample.int(10 ^ 4, 1),
+           seed_val = sample.int(10^4, 1),
            skip = FALSE,
            id = rand_id("impute_bag")) {
-    if (is.null(impute_with))
+    if (is.null(impute_with)) {
       rlang::abort("Please list some variables in `impute_with`")
+    }
     add_step(
       recipe,
       step_impute_bag_new(
@@ -138,10 +141,10 @@ step_bagimpute <-
            trees = 25,
            models = NULL,
            options = list(keepX = FALSE),
-           seed_val = sample.int(10 ^ 4, 1),
+           seed_val = sample.int(10^4, 1),
            skip = FALSE,
            id = rand_id("impute_bag")) {
-    lifecycle::deprecate_warn(
+    lifecycle::deprecate_stop(
       when = "0.1.16",
       what = "recipes::step_bagimpute()",
       with = "recipes::step_impute_bag()"
@@ -187,13 +190,20 @@ bag_wrap <- function(vars, dat, opt, seed_val) {
     dat[[vars$y]] <- factor(dat[[vars$y]])
   }
 
-  if (!is.null(seed_val) && !is.na(seed_val))
+  if (!is.null(seed_val) && !is.na(seed_val)) {
     set.seed(seed_val)
+  }
 
-  out <- do.call("ipredbagg",
-                 c(list(y = dat[, vars$y],
-                        X = dat[, vars$x, drop = FALSE]),
-                   opt))
+  out <- do.call(
+    "ipredbagg",
+    c(
+      list(
+        y = dat[, vars$y],
+        X = dat[, vars$x, drop = FALSE]
+      ),
+      opt
+    )
+  )
   out$..imp_vars <- vars$x
   out
 }
@@ -206,8 +216,10 @@ impute_var_lists <- function(to_impute, impute_using, training, info) {
 
   var_lists <- vector(mode = "list", length = length(to_impute))
   for (i in seq_along(var_lists)) {
-    var_lists[[i]] <- list(y = to_impute[i],
-                           x = impute_using[!(impute_using %in% to_impute[i])])
+    var_lists[[i]] <- list(
+      y = to_impute[i],
+      x = impute_using[!(impute_using %in% to_impute[i])]
+    )
   }
   var_lists
 }
@@ -253,9 +265,12 @@ prep.step_bagimpute <- prep.step_impute_bag
 
 #' @export
 bake.step_impute_bag <- function(object, new_data, ...) {
+  check_new_data(names(object$models), object, new_data)
+
   missing_rows <- !complete.cases(new_data)
-  if (!any(missing_rows))
+  if (!any(missing_rows)) {
     return(new_data)
+  }
 
   old_data <- new_data
   for (i in seq(along.with = object$models)) {
@@ -275,8 +290,7 @@ bake.step_impute_bag <- function(object, new_data, ...) {
       }
     }
   }
-  ## changes character to factor!
-  as_tibble(new_data)
+  new_data
 }
 
 #' @export
@@ -303,8 +317,10 @@ imp_vars <- function(...) quos(...)
 #' @export
 tidy.step_impute_bag <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = names(x$models),
-                  model = unname(x$models))
+    res <- tibble(
+      terms = names(x$models),
+      model = unname(x$models)
+    )
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names, model = list(NULL))
