@@ -30,20 +30,23 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #' `terms` (the selectors or variables selected) and `denom` is returned.
+#'
+#' @template case-weights-not-supported
+#'
 #' @family multivariate transformation steps
 #' @export
-#' @examples
+#' @examplesIf rlang::is_installed("modeldata")
 #' library(recipes)
-#' library(modeldata)
-#' data(biomass)
+#' data(biomass, package = "modeldata")
 #'
 #' biomass$total <- apply(biomass[, 3:7], 1, sum)
-#' biomass_tr <- biomass[biomass$dataset == "Training",]
-#' biomass_te <- biomass[biomass$dataset == "Testing",]
+#' biomass_tr <- biomass[biomass$dataset == "Training", ]
+#' biomass_te <- biomass[biomass$dataset == "Testing", ]
 #'
 #' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen +
-#'                     sulfur + total,
-#'               data = biomass_tr)
+#'   sulfur + total,
+#' data = biomass_tr
+#' )
 #'
 #' ratio_recipe <- rec %>%
 #'   # all predictors over total
@@ -55,26 +58,27 @@
 #'
 #' ratio_data <- bake(ratio_recipe, biomass_te)
 #' ratio_data
-
 step_ratio <-
   function(recipe,
            ...,
            role = "predictor",
            trained = FALSE,
            denom = denom_vars(),
-           naming = function(numer, denom)
-             make.names(paste(numer, denom, sep = "_o_")),
+           naming = function(numer, denom) {
+             make.names(paste(numer, denom, sep = "_o_"))
+           },
            columns = NULL,
            keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("ratio")) {
-    if (is_empty(denom))
+    if (is_empty(denom)) {
       rlang::abort(
         paste0(
           "Please supply at least one denominator variable specification. ",
           "See ?selections."
         )
       )
+    }
     add_step(
       recipe,
       step_ratio_new(
@@ -119,10 +123,12 @@ prep.step_ratio <- function(x, training, info = NULL, ...) {
   col_names <- tibble::as_tibble(col_names)
   col_names <- col_names[!(col_names$top == col_names$bottom), ]
 
-  if (any(info$type[info$variable %in% col_names$top] != "numeric"))
+  if (any(info$type[info$variable %in% col_names$top] != "numeric")) {
     rlang::abort("The ratio variables should be numeric")
-  if (any(info$type[info$variable %in% col_names$bottom] != "numeric"))
+  }
+  if (any(info$type[info$variable %in% col_names$bottom] != "numeric")) {
     rlang::abort("The ratio variables should be numeric")
+  }
 
   step_ratio_new(
     terms = x$terms,
@@ -139,6 +145,8 @@ prep.step_ratio <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_ratio <- function(object, new_data, ...) {
+  check_new_data(unname(object$columns$top), object, new_data)
+
   res <- purrr::map2(
     new_data[, object$columns$top],
     new_data[, object$columns$bottom],
@@ -160,9 +168,6 @@ bake.step_ratio <- function(object, new_data, ...) {
     union_cols <- union(object$columns$top, object$columns$bottom)
     new_data <- new_data[, !(colnames(new_data) %in% union_cols), drop = FALSE]
   }
-
-  if (!is_tibble(new_data))
-    new_data <- as_tibble(new_data)
   new_data
 }
 
@@ -182,14 +187,17 @@ denom_vars <- function(...) quos(...)
 #' @export
 tidy.step_ratio <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = unname(x$columns$top),
-                  denom = unname(x$columns$bottom))
+    res <- tibble(
+      terms = unname(x$columns$top),
+      denom = unname(x$columns$bottom)
+    )
   } else {
-    res <- tidyr::crossing(terms = sel2char(x$terms),
-                           denom = sel2char(x$denom))
+    res <- tidyr::crossing(
+      terms = sel2char(x$terms),
+      denom = sel2char(x$denom)
+    )
     res <- as_tibble(res)
   }
   res$id <- x$id
   arrange(res, terms, denom)
 }
-
