@@ -28,24 +28,25 @@
 #' `terms` (the columns that will be affected) and `value` (the factor
 #'  levels that is used for the new value) is returned.
 #'
-#' @examples
-#' library(modeldata)
-#' data(okc)
+#' @template case-weights-not-supported
+#'
+#' @examplesIf rlang::is_installed("modeldata")
+#' data(Sacramento, package = "modeldata")
 #'
 #' rec <-
-#'   recipe(~ diet + location, data = okc) %>%
-#'   step_unknown(diet, new_level = "unknown diet") %>%
-#'   step_unknown(location, new_level = "unknown location") %>%
+#'   recipe(~ city + zip, data = Sacramento) %>%
+#'   step_unknown(city, new_level = "unknown city") %>%
+#'   step_unknown(zip, new_level = "unknown zip") %>%
 #'   prep()
 #'
-#' table(bake(rec, new_data = NULL) %>% pull(diet),
-#'       okc %>% pull(diet),
-#'       useNA = "always") %>%
+#' table(bake(rec, new_data = NULL) %>% pull(city),
+#'   Sacramento %>% pull(city),
+#'   useNA = "always"
+#' ) %>%
 #'   as.data.frame() %>%
 #'   dplyr::filter(Freq > 0)
 #'
 #' tidy(rec, number = 1)
-
 step_unknown <-
   function(recipe,
            ...,
@@ -87,27 +88,30 @@ step_unknown_new <-
 prep.step_unknown <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
   col_check <- dplyr::filter(info, variable %in% col_names)
-  if (any(col_check$type != "nominal"))
+  if (any(col_check$type != "nominal")) {
     rlang::abort(
       paste0(
         "Columns must be character or factor: ",
         paste0(col_check$variable[col_check$type != "nominal"],
-               collapse = ", ")
+          collapse = ", "
+        )
       )
     )
+  }
 
   # Get existing levels and their factor type (i.e. ordered)
   objects <- lapply(training[, col_names], get_existing_values)
   # Check to make sure that there are not duplicate levels
   level_check <-
     map_lgl(objects, function(x, y) y %in% x, y = x$new_level)
-  if (any(level_check))
+  if (any(level_check)) {
     rlang::abort(
       paste0(
         "Columns already contain a level '", x$new_level, "': ",
         paste0(names(level_check)[level_check], collapse = ", ")
       )
     )
+  }
 
   step_unknown_new(
     terms = x$terms,
@@ -122,6 +126,7 @@ prep.step_unknown <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_unknown <- function(object, new_data, ...) {
+  check_new_data(names(object$objects), object, new_data)
   for (i in names(object$objects)) {
     new_data[[i]] <-
       ifelse(is.na(new_data[[i]]), object$new_level, as.character(new_data[[i]]))
@@ -132,18 +137,18 @@ bake.step_unknown <- function(object, new_data, ...) {
       warn_new_levels(
         new_data[[i]],
         new_levels,
-        paste0("\nNew levels will be coerced to `NA` by `step_unknown()`.",
-               "\nConsider using `step_novel()` before `step_unknown()`.")
+        paste0(
+          "\nNew levels will be coerced to `NA` by `step_unknown()`.",
+          "\nConsider using `step_novel()` before `step_unknown()`."
+        )
       )
     }
 
     new_data[[i]] <-
       factor(new_data[[i]],
-             levels = new_levels,
-             ordered = attributes(object$object[[i]])$is_ordered)
-  }
-  if (!is_tibble(new_data)) {
-    new_data <- as_tibble(new_data)
+        levels = new_levels,
+        ordered = attributes(object$object[[i]])$is_ordered
+      )
   }
   new_data
 }
@@ -159,12 +164,16 @@ print.step_unknown <-
 #' @export
 tidy.step_unknown <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = names(x$objects),
-                  value = rep(x$new_level, length(x$objects)))
+    res <- tibble(
+      terms = names(x$objects),
+      value = rep(x$new_level, length(x$objects))
+    )
   } else {
     term_names <- sel2char(x$terms)
-    res <- tibble(terms = term_names,
-                  value = rep(x$new_level, length(term_names)))
+    res <- tibble(
+      terms = term_names,
+      value = rep(x$new_level, length(term_names))
+    )
   }
   res$id <- x$id
   res
