@@ -4,12 +4,14 @@ library(tibble)
 
 n <- 20
 set.seed(1)
-ex_dat <- data.frame(x1 = exp(rnorm(n, mean = .1)),
-                     x2 = 1/abs(rnorm(n)),
-                     x3 = rep(1:2, each = n/2),
-                     x4 = rexp(n))
+ex_dat <- data.frame(
+  x1 = exp(rnorm(n, mean = .1)),
+  x2 = 1 / abs(rnorm(n)),
+  x3 = rep(1:2, each = n / 2),
+  x4 = rexp(n)
+)
 
-test_that('simple log trans', {
+test_that("simple log trans", {
   rec <- recipe(~., data = ex_dat) %>%
     step_log(x1, x2, x3, x4)
 
@@ -22,7 +24,7 @@ test_that('simple log trans', {
 })
 
 
-test_that('alt base', {
+test_that("alt base", {
   rec <- recipe(~., data = ex_dat) %>%
     step_log(x1, x2, x3, x4, base = pi)
 
@@ -34,7 +36,7 @@ test_that('alt base', {
   expect_equal(rec_trans, exp_res)
 })
 
-test_that('alt offset', {
+test_that("alt offset", {
   rec <- recipe(~., data = ex_dat) %>%
     step_log(x1, x2, x3, x4, base = pi, offset = 0.1)
 
@@ -46,24 +48,23 @@ test_that('alt offset', {
   expect_equal(rec_trans, exp_res)
 })
 
-test_that('printing', {
+test_that("printing", {
   rec <- recipe(~., data = ex_dat) %>%
     step_log(x1, x2, x3, x4)
-  expect_output(print(rec))
-  expect_output(prep(rec, training = ex_dat, verbose = TRUE))
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
 })
 
 
-test_that('signed arg', {
-  ex_with_neg <- data.frame(x = c(-1* exp(2), -0.5, 0.5, exp(2)))
+test_that("signed arg", {
+  ex_with_neg <- data.frame(x = c(-1 * exp(2), -0.5, 0.5, exp(2)))
   rec <- recipe(ex_with_neg, ~x) %>%
     step_log(x, signed = TRUE) %>%
     prep()
   rec2 <- recipe(ex_with_neg, ~x) %>%
     step_log(x, offset = 2, signed = TRUE)
   expect_equal(bake(rec, ex_with_neg), tibble(x = c(-2, 0, 0, 2)))
-  expect_warning(prep(rec2),
-                 "When signed is TRUE, offset will be ignored")
+  expect_snapshot(prep(rec2))
 })
 
 test_that("empty selection prep/bake is a no-op", {
@@ -103,3 +104,15 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(~., data = ex_dat) %>%
+    step_log(x1, x2, x3, x4) %>%
+    update_role(x1, x2, x3, x4, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  rec_trained <- prep(rec, training = ex_dat, verbose = FALSE)
+
+  expect_error(bake(rec_trained, new_data = ex_dat[, 1:3]),
+               class = "new_data_missing_column")
+})
