@@ -13,13 +13,13 @@ ex_dat <- data.frame(
   stringsAsFactors = FALSE
 )
 
-rec <- recipe(~ ., data = ex_dat)
+rec <- recipe(~., data = ex_dat)
 
-test_that('basic functionality', {
+test_that("basic functionality", {
   ex_1 <- rec %>%
     step_string2factor(w, x) %>%
     prep(ex_dat, strings_as_factors = FALSE) %>%
-    juice
+    juice()
   expect_equal(class(ex_1$w), "factor")
   expect_equal(class(ex_1$x), "factor")
   expect_equal(levels(ex_1$w), letters[1:3])
@@ -35,13 +35,13 @@ test_that('basic functionality', {
   expect_equal(levels(ex_2$x), LETTERS[1:2])
 })
 
-test_that('bad args', {
-  expect_error(
-  rec %>%
-    step_string2factor(w, n) %>%
-    prep(ex_dat)
+test_that("bad args", {
+  expect_snapshot(error = TRUE,
+    rec %>%
+      step_string2factor(w, n) %>%
+      prep(ex_dat)
   )
-  expect_error(
+  expect_snapshot(error = TRUE,
     rec %>%
       step_string2factor(n, ordered = "yes") %>%
       prep(ex_dat)
@@ -49,15 +49,15 @@ test_that('bad args', {
 })
 
 
-test_that('printing', {
+test_that("printing", {
   ex_3 <- rec %>%
     step_string2factor(w, x) %>%
     prep(ex_dat, strings_as_factors = FALSE)
-  expect_output(print(ex_3))
-  expect_output(prep(ex_3, training = ex_dat, verbose = TRUE))
+  expect_snapshot(print(ex_3))
+  expect_snapshot(prep(ex_3))
 })
 
-test_that('pre-made factors', {
+test_that("pre-made factors", {
   ex_1 <- rec %>%
     step_string2factor(w, x, y, z) %>%
     prep(ex_dat, strings_as_factors = FALSE) %>%
